@@ -5,14 +5,13 @@ platform-independent data files."""
 
 # contributed by Bastian Kleineidam
 
-__revision__ = "$Id: install_data.py,v 1.19 2001/09/04 20:42:08 akuchling Exp $"
+__revision__ = "$Id: install_data.py 76849 2009-12-15 06:29:19Z tarek.ziade $"
 
 import os
-from types import StringType
 from distutils.core import Command
 from distutils.util import change_root, convert_path
 
-class install_data (Command):
+class install_data(Command):
 
     description = "install data files"
 
@@ -27,26 +26,25 @@ class install_data (Command):
 
     boolean_options = ['force']
 
-    def initialize_options (self):
+    def initialize_options(self):
         self.install_dir = None
         self.outfiles = []
         self.root = None
         self.force = 0
-
         self.data_files = self.distribution.data_files
         self.warn_dir = 1
 
-    def finalize_options (self):
+    def finalize_options(self):
         self.set_undefined_options('install',
                                    ('install_data', 'install_dir'),
                                    ('root', 'root'),
                                    ('force', 'force'),
                                   )
 
-    def run (self):
+    def run(self):
         self.mkpath(self.install_dir)
         for f in self.data_files:
-            if type(f) == StringType:
+            if isinstance(f, str):
                 # it's a simple file, so copy it
                 f = convert_path(f)
                 if self.warn_dir:
@@ -76,8 +74,8 @@ class install_data (Command):
                         (out, _) = self.copy_file(data, dir)
                         self.outfiles.append(out)
 
-    def get_inputs (self):
+    def get_inputs(self):
         return self.data_files or []
 
-    def get_outputs (self):
+    def get_outputs(self):
         return self.outfiles
